@@ -216,7 +216,7 @@ class Postgres(object):
                     self.cursor.execute(
                         'create table {} ({});'.format(table_name, sql_str))
                     self.cursor.execute(add_conflict_sql)
-                    logger.info(f'create table: {sql_str}')
+                    logger.info('create table: %s' %sql_str)
             else:
                 if len(column_list) - len(constraint_columns) == 1:
                     sql = '''
